@@ -8,7 +8,7 @@
 from __future__ import annotations
 
 import logging
-from typing import Any, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 import cv2
 
@@ -35,7 +35,6 @@ class Box:
     """
 
     def __init__(self, xmin: int, ymin: int, xmax: int, ymax: int) -> None:
-
         if xmin >= xmax:
             raise ValueError(f"xmin={xmin} has to be < xmax={xmax}")
 
@@ -52,7 +51,6 @@ class Box:
         self.__ymax: int = ymax
 
     def __eq__(self, other: object) -> bool:
-
         if isinstance(other, Box):
             return (
                 self.xmin == other.xmin
@@ -70,6 +68,17 @@ class Box:
             f")"
         )
 
+    def to_dict(self) -> Dict[str, int]:
+        return {
+            "xmin": self.xmin,
+            "ymin": self.ymin,
+            "xmax": self.xmax,
+            "ymax": self.ymax,
+        }
+
+    def to_json(self) -> Any:
+        return self.to_dict()
+
     @property
     def xmin(self) -> int:
         return self.__xmin
@@ -125,7 +134,6 @@ class Box:
             ymin = max(0, ymin)
 
         if box_format == ObjectDetectionBBoxFormats.XYWH:
-
             width = box_list[2]
             if width < 0:
                 raise ValueError("Can not build a box with negative width")
