@@ -8,7 +8,7 @@
 from __future__ import annotations
 
 import math
-from typing import Optional
+from typing import Any, Dict, Optional
 
 from mlcvzoo_base.api.data.class_identifier import ClassIdentifier
 from mlcvzoo_base.api.interfaces import Perception
@@ -87,8 +87,54 @@ class Classification(Perception):
     def score(self) -> float:
         return self.__score
 
-    def copy_classification(self, class_identifier: ClassIdentifier) -> Classification:
+    def to_dict(self, raw_type: bool = False, reduced: bool = False) -> Dict[str, Any]:
+        if reduced:
+            return {
+                "class_id": self.class_id,
+                "class_name": self.class_name,
+                "model_class_id": self.model_class_identifier.class_id,
+                "model_class_name": self.model_class_identifier.class_name,
+                "score": self.score,
+            }
+        else:
+            return {
+                "class_identifier": self.class_identifier
+                if raw_type
+                else self.class_identifier.to_dict(),
+                "model_class_identifier": self.model_class_identifier
+                if raw_type
+                else self.model_class_identifier.to_dict(),
+                "score": self.score,
+            }
 
+    @staticmethod
+    def from_dict(input_dict: Dict[str, Any], reduced: bool = False) -> Classification:
+        # fmt: off
+        if reduced:
+            return Classification(**{
+                "class_identifier": ClassIdentifier(**{
+                    "class_id": input_dict["class_id"],
+                    "class_name": input_dict["class_name"],
+                }),
+                "model_class_identifier": ClassIdentifier(**{
+                    "class_id": input_dict["model_class_id"],
+                    "class_name": input_dict["model_class_name"],
+                }),
+                "score": input_dict["score"],
+            })
+        else:
+            return Classification(**{
+                "class_identifier": ClassIdentifier(
+                    **input_dict["class_identifier"]
+                ),
+                "model_class_identifier": ClassIdentifier(
+                    **input_dict["model_class_identifier"]
+                ),
+                "score": input_dict["score"],
+            })
+        # fmt: on
+
+    def copy_classification(self, class_identifier: ClassIdentifier) -> Classification:
         return Classification(
             class_identifier=class_identifier,
             score=self.score,
