@@ -11,9 +11,11 @@ from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from typing import Dict, Generic, Optional, TypeVar
 
+from mlcvzoo_base.api.configuration import InferenceConfig
 from mlcvzoo_base.api.data.annotation_class_mapper import AnnotationClassMapper
 
 NetType = TypeVar("NetType")
+NetConfigurationType = TypeVar("NetConfigurationType", bound=InferenceConfig)
 
 
 @dataclass
@@ -23,7 +25,7 @@ class Perception:
     models of the MLCVZoo. This includes ground-truth data as well as
     predicted objects. Dataclasses should inherit from this class in
     order to be used in a predict(...) method of the model class,
-    or sub-classes of the model class e.g. for any object detector,
+    or subclasses of the model class e.g. for any object detector,
     character classifier, OCR, etc.
     """
 
@@ -58,7 +60,7 @@ class Classifiable(ABC):
         """
         The prediction output of classifiable models contains representations of classes
         as IDs. These IDs are associated with real world instances like car, truck, person etc.
-        Therefore each classifiable model has to provide a dictionary that indicates how the
+        Therefore, each classifiable model has to provide a dictionary that indicates how the
         class IDs are mapped to class names.
 
         Returns:
@@ -80,7 +82,7 @@ class Trainable(ABC):
         """
         The method trains the model.
 
-        Sub-classes must implement the training, including proper use of the
+        Subclasses must implement the training, including proper use of the
         model configuration and parameters.
 
         Returns:
@@ -88,16 +90,36 @@ class Trainable(ABC):
         """
         raise NotImplementedError("Must be implemented by sub-class: train(...).")
 
+    @abstractmethod
+    def get_training_output_dir(self) -> str:
+        """
+        Returns:
+            The directory where a trainable model is storing its training output artefacts
+        """
+        raise NotImplementedError(
+            "Must be implemented by sub-class: get_training_output_dir(...)."
+        )
 
-class NetBased(ABC, Generic[NetType]):
+
+class NetBased(ABC, Generic[NetType, NetConfigurationType]):
     """
     The interface represents the super-class for any net based model. The term "net"
     in this context is associated with any kind of neural network.
     """
 
     def __init__(self, net: Optional[NetType]):
+        # A net attribute is not always necessary, e.g. there are trainable models,
+        # that don't require a net attribute during training
         self.net: Optional[NetType] = net
 
+    @property
+    def inference_config(self) -> Optional[NetConfigurationType]:
+        """
+        Returns:
+           The inference config of this NetBased instance
+        """
+        return None
+
     def get_net(self) -> Optional[NetType]:
         """
         Returns:
@@ -119,3 +141,10 @@ class NetBased(ABC, Generic[NetType]):
 
         """
         raise NotImplementedError("Must be implemented by sub-class: restore(...)")
+
+    def get_checkpoint_filename_suffix(self) -> str:
+        """
+        Returns:
+            The suffix of the associated checkpoint files like .pth (pytorch) or .h5 (tensorflow)
+        """
+        return ""
