@@ -8,13 +8,14 @@
 import logging
 from typing import Type
 
-from mlcvzoo_base.api.configuration import Configuration
+from config_builder import BaseConfigClass
+
 from mlcvzoo_base.api.registry import MLCVZooRegistry
 
 logger = logging.getLogger(__name__)
 
 
-class ConfigRegistry(MLCVZooRegistry[Type[Configuration]]):
+class ConfigRegistry(MLCVZooRegistry[Type[BaseConfigClass]]):
 
     """
     Class to provide a registry for configuration constructors
