@@ -6,14 +6,14 @@
 from typing import Optional
 
 import related
+from attr import define
 from config_builder import BaseConfigClass
 
 from mlcvzoo_base.configuration.structs import DeviceQueryTypes
 
 
-@related.mutable(strict=True)
+@define
 class ModelTimerDeviceQueryConfig(BaseConfigClass):
-
     device_index: Optional[int] = related.ChildField(cls=int)
     query_type: str = related.StringField()
 
