@@ -9,10 +9,11 @@ Module for parsing information from yaml in python accessible attributes for usi
 from typing import Dict, List, Optional
 
 import related
+from attr import define
 from config_builder import BaseConfigClass
 
 
-@related.mutable(strict=True)
+@define
 class MLFlowPostgresSQLConfig(BaseConfigClass):
     """Class for parsing information about a SQL sever used for storing experiment information"""
 
@@ -22,27 +23,20 @@ class MLFlowPostgresSQLConfig(BaseConfigClass):
     database_name: str = related.StringField(default="mlflowdb")
 
 
-@related.mutable(strict=True)
+@define
 class MLFlowFileConfig(BaseConfigClass):
     """Class for parsing information about a directory used for storing experiment information"""
 
     logging_dir: str = related.StringField()
 
 
-@related.mutable(strict=True)
+@define
 class MLFlowConfig(BaseConfigClass):
     """
     Class for parsing general information about path handling and also further
     configuration information in respective hierarchy
     """
 
-    mutual_attribute_map: Dict[str, List[str]] = {
-        "MLFlowConfig": [
-            "mlflow_postgressql_config",
-            "mlflow_file_config",
-        ]
-    }
-
     artifact_location: str = related.StringField()
 
     mlflow_postgressql_config: Optional[MLFlowPostgresSQLConfig] = related.ChildField(
@@ -52,3 +46,10 @@ class MLFlowConfig(BaseConfigClass):
     mlflow_file_config: Optional[MLFlowFileConfig] = related.ChildField(
         cls=MLFlowFileConfig, required=False, default=None
     )
+
+    @property
+    def _mutual_attributes(self) -> List[str]:
+        return [
+            "mlflow_postgressql_config",
+            "mlflow_file_config",
+        ]
