@@ -8,10 +8,11 @@ Module for configuring the visualization of model outputs
 """
 
 import related
+from attr import define
 from config_builder import BaseConfigClass
 
 
-@related.mutable(strict=True)
+@define
 class VisualizationConfig(BaseConfigClass):
     """Class for parsing information for visualization"""
 
