@@ -46,13 +46,17 @@ class CSVAnnotationBuilder(AnnotationBuilder):
         annotation_dir: str,
         replacement_string: str,
     ) -> BaseAnnotation:
-
         if not os.path.isdir(image_dir):
             raise ValueError(
                 f"image_dir '{image_dir}' does not exist. Please provide a valid directory"
             )
 
-        (csv_annotation_path, csv_image_path, image_shape, bounding_boxes,) = self.__init_from_csv(
+        (
+            csv_annotation_path,
+            csv_image_path,
+            image_shape,
+            bounding_boxes,
+        ) = self.__init_from_csv(
             image_dir=image_dir,
             annotation_dir=annotation_dir,
         )
