@@ -142,7 +142,6 @@ class CSVAnnotationWriter(AnnotationWriter):
     def __annotation_to_csv_entry_list(
         self, annotations: List[BaseAnnotation], output_string_format: str
     ) -> Tuple[List[str], BaseDatasetInfo]:
-
         csv_entry_list: List[str] = list()
 
         # TODO: do we need this statistic?
@@ -152,7 +151,6 @@ class CSVAnnotationWriter(AnnotationWriter):
         )
 
         for annotation in annotations:
-
             annotation = replace_dir_by_index(annotation=annotation)
 
             # Write annotation data to csv
@@ -235,11 +233,17 @@ class CSVAnnotationWriter(AnnotationWriter):
                     random_state=self.write_output_config.random_state,
                 )
 
-                (train_csv_entry_list, train_dataset_info,) = self.__annotation_to_csv_entry_list(
+                (
+                    train_csv_entry_list,
+                    train_dataset_info,
+                ) = self.__annotation_to_csv_entry_list(
                     annotations=train_list, output_string_format=output_string_format
                 )
 
-                (eval_csv_entry_list, eval_dataset_info,) = self.__annotation_to_csv_entry_list(
+                (
+                    eval_csv_entry_list,
+                    eval_dataset_info,
+                ) = self.__annotation_to_csv_entry_list(
                     annotations=eval_list, output_string_format=output_string_format
                 )
 
@@ -248,7 +252,10 @@ class CSVAnnotationWriter(AnnotationWriter):
 
             # VALIDATION
             else:
-                (train_csv_entry_list, train_dataset_info,) = self.__annotation_to_csv_entry_list(
+                (
+                    train_csv_entry_list,
+                    train_dataset_info,
+                ) = self.__annotation_to_csv_entry_list(
                     annotations=annotations, output_string_format=output_string_format
                 )
 
@@ -257,7 +264,6 @@ class CSVAnnotationWriter(AnnotationWriter):
         return list_splits
 
     def __replace_file_name_placeholders(self, timestamp_string: str) -> None:
-
         assert self.write_output_config.csv_annotation is not None
 
         # TODO: add test
@@ -356,7 +362,6 @@ class CSVAnnotationWriter(AnnotationWriter):
 
     @staticmethod
     def __get_file_extension(output_string_format: str) -> str:
-
         if output_string_format == CSVOutputStringFormats.BASE:
             file_extension = ".csv"
         elif output_string_format == CSVOutputStringFormats.YOLO:
