@@ -239,7 +239,6 @@ class MetricsComputation:
     def __reset_main_dictionaries(
         self,
     ) -> None:
-
         for class_identifier in self.class_identifier_list:
             self.model_metrics.metrics_image_info_dict[str(class_identifier)] = dict()
 
@@ -264,7 +263,6 @@ class MetricsComputation:
                     ] = ODMetrics()
 
     def __reset_computing_dictionaries(self) -> None:
-
         for iou_thresh in self.iou_thresholds:
             self.computing_data.false_positives_dict[iou_thresh] = dict()
             self.computing_data.true_positives_dict[iou_thresh] = dict()
@@ -408,7 +406,6 @@ class MetricsComputation:
         # This is needed to be able to compute detailed metrics
         # for each class-id.
         for class_identifier in class_identifier_list:
-
             # Have to find all bounding-boxes for a specific class-id.
             # In order to have access to the information about the image-path,
             # we need to store an annotation object, rather than a single bounding-box.
@@ -452,7 +449,6 @@ class MetricsComputation:
         iou_thresh: float,
         bbox_size_type: str,
     ) -> None:
-
         if is_true_positive:
             tp_value = 1
             fp_value = 0
@@ -486,13 +482,11 @@ class MetricsComputation:
         iou_thresh: float,
         unmatched_gt_bounding_boxes: List[BoundingBox],
     ) -> List[BoundingBox]:
-
         bbox_size_type: str = get_bbox_size_type(bounding_box.box)
 
         # if the ground truth data for this image indicates that nothing has to be detected,
         # indicate this box as False-Positive right away!
         if len(unmatched_gt_bounding_boxes) == 0:
-
             self.__update_tp_fp_data(
                 is_true_positive=False,
                 iou_thresh=iou_thresh,
@@ -663,7 +657,6 @@ class MetricsComputation:
     def __get_gt_annotation(
         self, dataset_index: int, class_identifier: ClassIdentifier
     ) -> Tuple[Optional[BaseAnnotation], List[BoundingBox]]:
-
         # annotation object for gathering all ground truth bounding boxes for this image
         ground_truth_annotation: Optional[BaseAnnotation] = None
 
@@ -675,7 +668,6 @@ class MetricsComputation:
         # Iterate over all ground-truth annotations that containing bounding-box
         # information for this image (dataset_index) and the given class-id
         for gt_annotation in self._all_gt_annotations_dict[dataset_index][str(class_identifier)]:
-
             unmatched_gt_bounding_boxes.extend(
                 gt_annotation.get_bounding_boxes(include_segmentations=True)
             )
@@ -709,7 +701,6 @@ class MetricsComputation:
         class_name: Optional[str],
         class_identifier: Optional[ClassIdentifier] = None,
     ) -> None:
-
         if class_identifier is None:
             if class_id is not None:
                 logger.warning(
@@ -751,13 +742,14 @@ class MetricsComputation:
 
         # Iterate over all image indices
         for dataset_index in process_bar:
-
-            (ground_truth_annotation, unmatched_gt_bounding_boxes,) = self.__get_gt_annotation(
+            (
+                ground_truth_annotation,
+                unmatched_gt_bounding_boxes,
+            ) = self.__get_gt_annotation(
                 dataset_index=dataset_index, class_identifier=class_identifier
             )
 
             for iou_thresh in self.iou_thresholds:
-
                 # Iterate over all predicted annotations for this image and class-id
                 iou_unmatched_gt_bounding_boxes = copy.deepcopy(unmatched_gt_bounding_boxes)
 
@@ -765,7 +757,6 @@ class MetricsComputation:
                     for predicted_annotation in self._all_predicted_annotations_dict[
                         dataset_index
                     ][str(class_identifier)]:
-
                         for bounding_box in predicted_annotation.get_bounding_boxes(
                             include_segmentations=True
                         ):
@@ -814,7 +805,6 @@ class MetricsComputation:
         true_positives: np.ndarray,  # type: ignore[type-arg]
         false_positives: np.ndarray,  # type: ignore[type-arg]
     ) -> None:
-
         # compute recall and precision
         recall_values = true_positives / num_annotations
         precision_values = true_positives / np.maximum(
@@ -858,12 +848,9 @@ class MetricsComputation:
         ] = ODMetrics(TP=tp, FP=fp, FN=fn, PR=pr, RC=rc, F1=f1, AP=ap, COUNT=num_annotations)
 
     def __compute_metrics(self, class_identifier: ClassIdentifier) -> None:
-
         # TODO: Is this mAP computation? - separate from rest !
         for iou_thresh in self.iou_thresholds:
-
             for bbox_size_type in BBoxSizeTypes.get_values_as_list(class_type=BBoxSizeTypes):
-
                 num_annotations = self.computing_data.gt_counter_dict[bbox_size_type][
                     str(class_identifier)
                 ]
@@ -965,7 +952,6 @@ class MetricsComputation:
             ]
 
             for class_identifier in class_identifiers:
-
                 other_class_identifiers = copy.deepcopy(class_identifiers)
                 other_class_identifiers.remove(class_identifier)
 
@@ -1098,7 +1084,6 @@ class MetricsComputation:
             ]
 
             for class_identifier in class_identifiers:
-
                 other_class_identifiers: List[ClassIdentifier] = copy.deepcopy(class_identifiers)
                 other_class_identifiers.remove(class_identifier)
 
@@ -1201,7 +1186,6 @@ class MetricsComputation:
         class_img_metrics_info: MetricImageInfo,
         other_class_img_metrics_info: MetricImageInfo,
     ) -> METRIC_IMAGE_INFO_TYPE:
-
         if class_img_metrics_info.false_negative_matched_false_positive_annotation is not None:
             class_img_metrics_info.false_negative_matched_false_positive_annotation.bounding_boxes.append(
                 fn_bounding_box
