@@ -10,9 +10,8 @@ import inspect
 import logging
 from typing import Any, Dict, List, Optional, Type
 
-from related import to_dict
+from config_builder import BaseConfigClass
 
-from mlcvzoo_base.api.configuration import Configuration
 from mlcvzoo_base.api.model import ConfigurationType, DataType, Model, PredictionType
 from mlcvzoo_base.api.registry import MLCVZooRegistry
 from mlcvzoo_base.configuration.config_registry import ConfigRegistry
@@ -159,10 +158,10 @@ class ModelRegistry(MLCVZooRegistry[Type[Model[PredictionType, ConfigurationType
         return self._registry
 
     @property
-    def config_registry(self) -> Dict[str, Type[Configuration]]:
+    def config_registry(self) -> Dict[str, Type[BaseConfigClass]]:
         return self._config_registry._registry
 
-    def determine_config_class(self, model_type_name: str) -> Type[Configuration]:
+    def determine_config_class(self, model_type_name: str) -> Type[BaseConfigClass]:
         return self.config_registry[self._model_to_config_dict[model_type_name]]
 
     def determine_config_class_name(self, model_type_name: str) -> str:
@@ -203,7 +202,6 @@ class ModelRegistry(MLCVZooRegistry[Type[Model[PredictionType, ConfigurationType
     def register_model(
         self, model_type_name: str, model_constructor: Any, force: bool = False
     ) -> None:
-
         self.register_module(
             module_type_name=model_type_name, module_constructor=model_constructor, force=force
         )
@@ -232,9 +230,9 @@ class ModelRegistry(MLCVZooRegistry[Type[Model[PredictionType, ConfigurationType
             The created model instance
         """
 
-        if model_config.class_type in self._registry.keys():
+        model_type = self.get_model_type(class_type=model_config.class_type)
+        if model_type is not None:
             model: Model[PredictionType, ConfigurationType, DataType]
-            model_type = self._registry[model_config.class_type]
 
             init_params: List[Any] = list(inspect.getfullargspec(model_type.__init__).args)
             # We don't need self as parameter in the configuration
@@ -245,7 +243,7 @@ class ModelRegistry(MLCVZooRegistry[Type[Model[PredictionType, ConfigurationType
                 and STRING_REPLACEMENT_MAP_KEY in init_params
             ):
                 if string_replacement_map is None:
-                    string_replacement_map = to_dict(ReplacementConfig())
+                    string_replacement_map = ReplacementConfig().to_dict()
                 model_config.constructor_parameters[
                     STRING_REPLACEMENT_MAP_KEY
                 ] = string_replacement_map
