@@ -152,9 +152,7 @@ def encoding_safe_imread(filename: str) -> np.ndarray:  # type: ignore[type-arg]
     return image
 
 
-def extract_zip_data(
-    zip_path: str, zip_extract_dir: str, remove_existing: bool = True
-) -> None:
+def extract_zip_data(zip_path: str, zip_extract_dir: str, remove_existing: bool = True) -> None:
     """
     Extract the content of a zip file to a directory
 
